@@ -60,7 +60,6 @@ import java.util.concurrent.Callable;
 import java.util.concurrent.ExecutionException;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-import org.apache.http.client.HttpClient;
 import org.apache.http.client.utils.URIBuilder;
 import com.google.common.cache.Cache;
 import com.google.common.cache.CacheBuilder;
@@ -84,15 +83,10 @@ import com.openexchange.filestore.sproxyd.chunkstorage.ChunkStorage;
 import com.openexchange.filestore.sproxyd.chunkstorage.RdbChunkStorage;
 import com.openexchange.filestore.sproxyd.impl.EndpointPool;
 import com.openexchange.filestore.sproxyd.impl.SproxydClient;
-import com.openexchange.filestore.sproxyd.impl.SproxydConfig;
 import com.openexchange.filestore.utils.DefaultDatabaseAccess;
 import com.openexchange.filestore.utils.PropertyNameBuilder;
 import com.openexchange.java.Strings;
-import com.openexchange.metrics.MetricService;
-import com.openexchange.rest.client.httpclient.HttpClients;
-import com.openexchange.rest.client.httpclient.HttpClients.ClientConfig;
 import com.openexchange.server.ServiceLookup;
-import com.openexchange.timer.TimerService;
 
 /**
  * {@link SproxydFileStorageFactory}
@@ -115,7 +109,7 @@ public class SproxydFileStorageFactory implements FileStorageProvider, Interests
     private final ServiceLookup services;
 
     /** The cache holding initialized end-point pools */
-    private final Cache<String, SproxydConfig> sproxydConfigCache;
+    private final Cache<String, EndpointPool> endpointPoolCache;
 
     /**
      * Initializes a new {@link SproxydFileStorageFactory}.
@@ -125,14 +119,13 @@ public class SproxydFileStorageFactory implements FileStorageProvider, Interests
     public SproxydFileStorageFactory(ServiceLookup services) {
         super();
         this.services = services;
-        sproxydConfigCache = CacheBuilder.newBuilder()
+        endpointPoolCache = CacheBuilder.newBuilder()
             .weakValues()
-            .removalListener(new RemovalListener<String, SproxydConfig>() {
+            .removalListener(new RemovalListener<String, EndpointPool>() {
 
                 @Override
-                public void onRemoval(RemovalNotification<String, SproxydConfig> notification) {
-                    notification.getValue().getEndpointPool().close();
-                    HttpClients.shutDown(notification.getValue().getHttpClient());
+                public void onRemoval(RemovalNotification<String, EndpointPool> notification) {
+                    notification.getValue().close();
                 }
             })
             .build();
@@ -284,8 +277,7 @@ public class SproxydFileStorageFactory implements FileStorageProvider, Interests
      * @return The client
      */
     private SproxydClient initClient(String filestoreID, String prefix) throws OXException {
-        SproxydConfig sproxydConfig = initSproxydConfig(filestoreID);
-        return new SproxydClient(sproxydConfig, prefix);
+        return new SproxydClient(services, initSproxydConfig(filestoreID), prefix, filestoreID);
     }
 
     /**
@@ -295,11 +287,11 @@ public class SproxydFileStorageFactory implements FileStorageProvider, Interests
      * @return The endpoint pool
      * @throws OXException If endpoint pool cannot be initialized
      */
-    private SproxydConfig initSproxydConfig(String filestoreID) throws OXException {
-        SproxydConfig sproxydConfig = sproxydConfigCache.getIfPresent(filestoreID);
-        if (sproxydConfig == null) {
+    private EndpointPool initSproxydConfig(String filestoreID) throws OXException {
+        EndpointPool endpointPool = endpointPoolCache.getIfPresent(filestoreID);
+        if (endpointPool == null) {
             try {
-                sproxydConfig = sproxydConfigCache.get(filestoreID, new SproxydConfigLoaderCallable(filestoreID, this));
+                endpointPool = endpointPoolCache.get(filestoreID, new EndpointPoolLoaderCallable(filestoreID, this));
             } catch (ExecutionException | UncheckedExecutionException e) {
                 Throwable cause = e.getCause();
                 if (cause instanceof OXException) {
@@ -308,7 +300,7 @@ public class SproxydFileStorageFactory implements FileStorageProvider, Interests
                 throw OXException.general("Failed initializing S3 client.", cause);
             }
         }
-        return sproxydConfig;
+        return endpointPool;
     }
 
     /**
@@ -318,7 +310,7 @@ public class SproxydFileStorageFactory implements FileStorageProvider, Interests
      * @return The new endpoint pool
      * @throws OXException If endpoint pool cannot be initialized
      */
-    SproxydConfig doInitSproxydConfig(String filestoreID) throws OXException {
+    EndpointPool doInitSproxydConfig(String filestoreID) throws OXException {
         ConfigurationService configService = services.getService(ConfigurationService.class);
         PropertyNameBuilder nameBuilder = new PropertyNameBuilder("com.openexchange.filestore.sproxyd.");
         // End-point configuration
@@ -326,11 +318,6 @@ public class SproxydFileStorageFactory implements FileStorageProvider, Interests
         String path = requireProperty(filestoreID, "path", nameBuilder, configService);
         String hosts = requireProperty(filestoreID, "hosts", nameBuilder, configService);
 
-        // HTTP client configuration
-        int maxConnections = optIntProperty(filestoreID, "maxConnections", 100, nameBuilder, configService);
-        int maxConnectionsPerHost = optIntProperty(filestoreID, "maxConnectionsPerHost", 100, nameBuilder, configService);
-        int connectionTimeout = optIntProperty(filestoreID, "connectionTimeout", 5000, nameBuilder, configService);
-        int socketReadTimeout = optIntProperty(filestoreID, "socketReadTimeout", 15000, nameBuilder, configService);
         int heartbeatInterval = optIntProperty(filestoreID, "heartbeatInterval", 60000, nameBuilder, configService);
 
         List<String> urls = new LinkedList<String>();
@@ -365,14 +352,7 @@ public class SproxydFileStorageFactory implements FileStorageProvider, Interests
             throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("Invalid value for 'com.openexchange.filestore.sproxyd." + filestoreID + ".hosts': " + hosts);
         }
 
-        MetricService metrics = services.getServiceSafe(MetricService.class);
-        HttpClient httpClient = HttpClients.getHttpClient(ClientConfig.newInstance("sproxyd-" + filestoreID)
-            .setMaxTotalConnections(maxConnections)
-            .setMaxConnectionsPerRoute(maxConnectionsPerHost)
-            .setConnectionTimeout(connectionTimeout)
-            .setSocketReadTimeout(socketReadTimeout));
-        EndpointPool endpointPool = new EndpointPool(filestoreID, urls, httpClient, heartbeatInterval, services.getServiceSafe(TimerService.class), metrics);
-        return new SproxydConfig(httpClient, endpointPool);
+        return new EndpointPool(filestoreID, urls, heartbeatInterval, services);
     }
 
     /**
@@ -398,19 +378,19 @@ public class SproxydFileStorageFactory implements FileStorageProvider, Interests
 
     // -------------------------------------------------------------------------------------------------------------------------------------
 
-    private static class SproxydConfigLoaderCallable implements Callable<SproxydConfig> {
+    private static class EndpointPoolLoaderCallable implements Callable<EndpointPool> {
 
         private final String filestoreID;
         private final SproxydFileStorageFactory factory;
 
-        SproxydConfigLoaderCallable(String filestoreID, SproxydFileStorageFactory factory) {
+        EndpointPoolLoaderCallable(String filestoreID, SproxydFileStorageFactory factory) {
             super();
             this.filestoreID = filestoreID;
             this.factory = factory;
         }
 
         @Override
-        public SproxydConfig call() throws Exception {
+        public EndpointPool call() throws Exception {
             return factory.doInitSproxydConfig(filestoreID);
         }
     }
