@@ -57,6 +57,7 @@ import java.util.concurrent.Callable;
 import java.util.concurrent.TimeUnit;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.http.HttpResponse;
+import org.apache.http.client.HttpClient;
 import org.apache.http.client.methods.HttpDelete;
 import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.methods.HttpPut;
@@ -65,7 +66,8 @@ import com.openexchange.exception.OXException;
 import com.openexchange.filestore.FileStorageCodes;
 import com.openexchange.filestore.sproxyd.SproxydExceptionCode;
 import com.openexchange.java.util.UUIDs;
-import com.openexchange.rest.client.httpclient.HttpClients;
+import com.openexchange.rest.client.httpclient.HttpClientService;
+import com.openexchange.server.ServiceLookup;
 import net.jodah.failsafe.Failsafe;
 import net.jodah.failsafe.FailsafeException;
 import net.jodah.failsafe.RetryPolicy;
@@ -84,27 +86,35 @@ public class SproxydClient {
     /** The HTTP status code for a locked storage object */
     private static final int SC_LOCKED = 423;
 
-    final SproxydConfig sproxydConfig;
+    private final ServiceLookup services;
+    private final EndpointPool endpointPool;
     private final String prefix;
+    private final String filestoreID;
+
 
     /**
      * Initializes a new {@link SproxydClient}.
      *
-     * @param sproxydConfig The sproxyd config
+     * @param services The service lookup
+     * @param endpointPool The endpoint pool
      * @param prefix The prefix to use
+     * @param filestoreID The filestore ID
      */
-    public SproxydClient(SproxydConfig sproxydConfig, String prefix) {
+    public SproxydClient(ServiceLookup services, EndpointPool endpointPool, String prefix, String filestoreID) {
         super();
-        this.sproxydConfig = sproxydConfig;
+        this.services = services;
+        this.endpointPool = endpointPool;
         this.prefix = prefix;
+        this.filestoreID = filestoreID;
     }
 
     /**
-     * Shuts-down this Sproxyd client.
+     * Gets the end-point pool associated with this Sproxyd client.
+     *
+     * @return The end-point pool
      */
-    public void shutdown() {
-        sproxydConfig.getEndpointPool().close();
-        HttpClients.shutDown(sproxydConfig.getHttpClient());
+    public EndpointPool getEndpointPool() {
+        return endpointPool;
     }
 
     /**
@@ -127,7 +137,7 @@ public class SproxydClient {
                 try {
                     request = new HttpPut(endpoint.getObjectUrl(id));
                     request.setEntity(new InputStreamEntity(data, length));
-                    response = sproxydConfig.getHttpClient().execute(request);
+                    response = getHttpClient().execute(request);
                     int status = response.getStatusLine().getStatusCode();
                     if (HttpServletResponse.SC_OK == status || HttpServletResponse.SC_CREATED == status) {
                         return id;
@@ -179,7 +189,7 @@ public class SproxydClient {
                     if (0 < rangeStart || 0 < rangeEnd) {
                         get.addHeader("Range", "bytes=" + rangeStart + "-" + rangeEnd);
                     }
-                    response = sproxydConfig.getHttpClient().execute(get);
+                    response = getHttpClient().execute(get);
                     int status = response.getStatusLine().getStatusCode();
                     if (HttpServletResponse.SC_OK == status || HttpServletResponse.SC_PARTIAL_CONTENT == status) {
                         InputStream content = response.getEntity().getContent();
@@ -222,7 +232,7 @@ public class SproxydClient {
                 Endpoint endpoint = getEndpoint();
                 try {
                     delete = new HttpDelete(endpoint.getObjectUrl(id));
-                    response = sproxydConfig.getHttpClient().execute(delete);
+                    response = getHttpClient().execute(delete);
                     int status = response.getStatusLine().getStatusCode();
                     if (HttpServletResponse.SC_OK == status) {
                         return Boolean.TRUE;
@@ -265,7 +275,7 @@ public class SproxydClient {
      * @throws OXException If no end-point is available (i.e. all are blacklisted due to connection timeouts).
      */
     Endpoint getEndpoint() throws OXException {
-        Endpoint endpoint = sproxydConfig.getEndpointPool().get(prefix);
+        Endpoint endpoint = endpointPool.get(prefix);
         if (endpoint == null) {
             throw SproxydExceptionCode.STORAGE_UNAVAILABLE.create();
         }
@@ -278,6 +288,7 @@ public class SproxydClient {
      * @param endpoint The end-point for which the exception occurred.
      * @param e The exception
      * @return An OXException to re-throw
+     * @throws OXException
      */
     OXException handleCommunicationError(Endpoint endpoint, IOException e) throws OXException {
         if (org.apache.http.conn.ConnectionPoolTimeoutException.class.isInstance(e)) {
@@ -286,14 +297,24 @@ public class SproxydClient {
             return FileStorageCodes.IOERROR.create(e, e.getMessage());
         }
 
-        if (Utils.endpointUnavailable(endpoint.getBaseUrl(), sproxydConfig.getHttpClient())) {
+        if (Utils.endpointUnavailable(endpoint.getBaseUrl(), getHttpClient())) {
             LOG.warn("Sproxyd endpoint is unavailable: {}", endpoint);
-            sproxydConfig.getEndpointPool().blacklist(endpoint.getBaseUrl());
+            endpointPool.blacklist(endpoint.getBaseUrl());
         }
 
         return FileStorageCodes.IOERROR.create(e, e.getMessage());
     }
 
+    /**
+     * Gets the HTTP client to use to communicate with Sproxyd end-point.
+     *
+     * @return The HTTP client
+     * @throws OXException If HTTP client cannot be returned
+     */
+    HttpClient getHttpClient() throws OXException {
+        return services.getServiceSafe(HttpClientService.class).getHttpClient(filestoreID);
+    }
+
     // ----------------------------------------------- Failsafe retry stuff ----------------------------------------------------------------
 
     /**
